import {
  isPromise
} from "./chunk-L324TYGN.js";

// src/common/exec/mutex.ts
function useMutex() {
  let token = true;
  return (fn, elseFn) => {
    let executed = false;
    if (token) {
      token = false;
      try {
        fn();
        executed = true;
      } finally {
        token = true;
      }
    } else if (elseFn !== void 0) {
      elseFn();
    }
    return executed;
  };
}
function useAsyncMutex() {
  let token = true;
  return async (fn, elseFn) => {
    let executed = false;
    if (token) {
      token = false;
      try {
        const result = fn();
        if (isPromise(result))
          await result;
        executed = true;
      } finally {
        token = true;
      }
    } else if (elseFn !== void 0) {
      const result = elseFn();
      if (isPromise(result))
        await result;
    }
    return executed;
  };
}

export {
  useMutex,
  useAsyncMutex
};
//# sourceMappingURL=chunk-5OVSRAPG.js.map