import {
  isBoolean,
  isFunction,
  isInteger,
  isNumber,
  isObject,
  isString
} from "./chunk-V5ZQ2SFQ.js";
import {
  first
} from "./chunk-UOAPXGA4.js";

// src/common/schema/schema.ts
function preParse(obj, info) {
  if (obj == null) {
    if (info._default != null) {
      if (isFunction(info._default))
        obj = info._default();
      else
        obj = info._default;
    }
  }
  if (obj == null && info._optional === true)
    return void 0;
  if (obj == null)
    throw new Error("cannot be undefined");
  if (!info._check || info._check(obj))
    return obj;
  throw new Error("wrong value");
}
function generic(type, opt) {
  const info = {
    parse(obj) {
      return preParse(obj, this);
    },
    map(obj, fn) {
      return fn.call(this, obj, this) ?? obj;
    },
    _check() {
      return true;
    },
    ...opt,
    type,
    optional() {
      this._optional = true;
      return this;
    },
    default(value) {
      this._default = value;
      return this;
    },
    props(props) {
      this._props = props;
      return this;
    }
  };
  return info;
}
function string() {
  return generic("string", {
    _check: isString
  });
}
function number() {
  return generic("number", {
    _check: isNumber
  });
}
function int() {
  return generic("number", {
    _integer: true,
    _check: isInteger
  });
}
function boolean() {
  return generic("boolean", {
    _check: isBoolean
  });
}
function object(tobj) {
  const info = generic("object", {
    _object: tobj,
    parse(obj) {
      if (obj == null && this._optional === true)
        return void 0;
      const newObj = {};
      if (!isObject(obj))
        return new Error("expected object input");
      if (!isObject(this._object))
        return new Error("expected object definition");
      for (const [key, info2] of Object.entries(this._object)) {
        const value = info2.parse(obj[key]);
        if (value !== void 0)
          newObj[key] = value;
      }
      return newObj;
    },
    map(obj, fn) {
      const result = fn.call(this, obj, this);
      if (result !== void 0)
        return result;
      const newObj = {};
      if (obj) {
        for (const [key, info2] of Object.entries(this._object ?? {})) {
          const value = info2.map(obj[key], fn);
          if (value !== void 0)
            newObj[key] = value;
        }
      }
      return newObj;
    }
  });
  return info;
}
function union(options) {
  return generic(first(options)?.type ?? "any", {
    _union: options,
    _check(obj) {
      return this._union?.some((t) => t._check(obj)) ?? true;
    }
  });
}
function literal(value) {
  return generic("string", {
    _check: (v) => v === value
  });
}
function stringLiterals(value) {
  return generic("string", {
    _check: (v) => value.includes(v)
  });
}

export {
  string,
  number,
  int,
  boolean,
  object,
  union,
  literal,
  stringLiterals
};
//# sourceMappingURL=chunk-FRCOLULP.js.map