import {
  getSecureRandomIfPossible
} from "./chunk-QUKKMPRF.js";
import {
  cmp
} from "./chunk-GY34N3KU.js";

// src/common/data/array.ts
function arrayUnique(x) {
  return x.filter((n, index) => x.indexOf(n) === index);
}
function arrayMinus(x, y) {
  return arrayUnique(x.filter((n) => !y.includes(n)));
}
function arrayUnion(...a) {
  return arrayUnique(a.reduce((acc = [], value) => acc.concat(value), []));
}
function arrayFlatten(...list) {
  return list.flat(Number.POSITIVE_INFINITY);
}
function arrayIntersection(x, y) {
  return arrayUnique(x).filter((n) => y.includes(n));
}
function arraySymmetricDifference(x, y) {
  return arrayMinus(arrayUnion(x, y), arrayIntersection(x, y));
}
function arrayRemoveElement(arr, el) {
  if (arr && Array.isArray(arr)) {
    let index;
    while ((index = arr.indexOf(el)) !== -1)
      arr.splice(index, 1);
    return arr;
  }
  return [];
}
function arraySetElement(arr, el) {
  if (!arr.includes(el))
    arr.push(el);
  return arr;
}
function arrayFilterInPlace(array, fn) {
  array.splice(0, array.length, ...array.filter(fn));
  return array;
}
function arrayToggleInPlace(array, el) {
  const index = array.findIndex((e) => e === el);
  if (index >= 0)
    array.splice(index, 1);
  else array.push(el);
  return array;
}
function arrayEmptyInPlace(array) {
  array.splice(0, array.length);
  return array;
}
function arraySetArrayInPlace(array, newContent) {
  array.splice(0, array.length, ...newContent);
  return array;
}
function arraySorted(arr, cond = cmp) {
  return Array.from(arr).sort(cond);
}
function arraySortedNumbers(arr) {
  return arraySorted(arr, (l, r) => l - r);
}
function arrayIsEqual(array1, array2) {
  return array1.length === array2.length && array1.every((value, index) => value === array2[index]);
}
function arrayShuffleInPlace(array) {
  array.sort(() => getSecureRandomIfPossible() > 0.5 ? 1 : -1);
  return array;
}
function arrayShuffle(array) {
  return arrayShuffleInPlace(Array.from(array));
}
function arrayShuffleForce(array) {
  while (array.length > 1) {
    const copy = Array.from(array);
    arrayShuffleInPlace(copy);
    if (!arrayIsEqual(array, copy))
      return copy;
  }
  return array;
}
function arrayRandomElement(array) {
  return array[Math.floor(getSecureRandomIfPossible() * array.length)];
}
function arrayMax(...array) {
  return arrayFlatten(array).reduce(
    (acc, value) => acc != null ? value > acc ? value : acc : value,
    void 0
  );
}
function arrayMin(...array) {
  return arrayFlatten(array).reduce(
    (acc, value) => acc != null ? value < acc ? value : acc : value,
    void 0
  );
}
function arraySum(...array) {
  return arrayFlatten(array).reduce((acc, value) => acc + value, 0);
}
function arrayAvg(...array) {
  const flatArray = arrayFlatten(array);
  return flatArray.reduce((acc, value) => acc + value, 0) / flatArray.length;
}
function arrayBatches(array, chunckLength) {
  const chunks = [];
  let i = 0;
  const n = array.length;
  while (i < n)
    chunks.push(array.slice(i, i += chunckLength));
  return chunks;
}
function createArray(length = 0, item) {
  if (length <= 0)
    return [];
  const arr = Array.from({ length });
  for (let i = 0; i < length; i++)
    arr[i] = item instanceof Function ? item(i) : item;
  return arr;
}

export {
  arrayUnique,
  arrayMinus,
  arrayUnion,
  arrayFlatten,
  arrayIntersection,
  arraySymmetricDifference,
  arrayRemoveElement,
  arraySetElement,
  arrayFilterInPlace,
  arrayToggleInPlace,
  arrayEmptyInPlace,
  arraySetArrayInPlace,
  arraySorted,
  arraySortedNumbers,
  arrayIsEqual,
  arrayShuffleInPlace,
  arrayShuffle,
  arrayShuffleForce,
  arrayRandomElement,
  arrayMax,
  arrayMin,
  arraySum,
  arrayAvg,
  arrayBatches,
  createArray
};
//# sourceMappingURL=chunk-ITJJZ6AV.js.map