import {
  isSchemaObjectFlat
} from "./chunk-REMT6GKB.js";
import {
  assert
} from "./chunk-M6NJWFDP.js";
import {
  objectFilter,
  objectMap
} from "./chunk-MLCD7TOL.js";
import {
  valueToBoolean,
  valueToBooleanNotFalse,
  valueToInteger
} from "./chunk-QUQRUDWG.js";
import {
  toCamelCase
} from "./chunk-HJ22ULAI.js";

// src/common/schema/env.ts
function parseSchemaEnv(schema, env = process?.env ?? {}, prefix = "") {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const pl = prefix.length;
  if (pl > 0)
    env = objectFilter(env, (key) => key.startsWith(prefix));
  env = objectMap(env, (key, value) => {
    if (pl > 0)
      key = key.substring(pl);
    return [toCamelCase(key), value];
  });
  return objectMap(schema._object, (key, schema2) => {
    let value = env[toCamelCase(key)];
    if (schema2.type === "number") {
      value = valueToInteger(value, schema2._default);
    } else if (schema2.type === "boolean") {
      if (schema2._default === true)
        value = valueToBooleanNotFalse(value);
      else
        value = valueToBoolean(value, false);
    }
    return schema2.parse(value);
  });
}

export {
  parseSchemaEnv
};
//# sourceMappingURL=chunk-YGHVCY5N.js.map