import { Json } from '../types.cjs';

/**
 * Call a create function if key does not yet exist on an object. Returns the found or created object. Example:
 *
 * ```js
 * function createRoom(room, rooms) { return new Room() }
 * ensureKey(rooms, room, createRoom).enter()
 * ```
 */
declare function ensureKey<T>(obj: Record<string, T>, key: string, createFn: (key?: string, obj?: Record<string, T>) => T): T;
/**
 * Call a create function if key does not yet exist on an object. Returns the found or created object. Example:
 *
 * ```js
 * async function fetchItem(id, cache) { ... }
 * let data = await ensureKey(cache, id, fetchItem)
 * ```
 */
declare function ensureKeyAsync<T>(obj: Record<string, T>, key: string, createFn: (key?: string, obj?: Record<string, T>) => Promise<T>): Promise<T>;
declare function size(obj: any): any;
declare function first<T>(array?: T[]): T | undefined;
declare function last<T>(array?: T[]): T | undefined;
declare function empty(value: any): boolean;
declare function cloneObject<T>(obj: T): T;
declare function cloneJsonObject<T = Json>(obj: T): T;
/**
 * Cache result of a function. Same arguments have to always return the same result in order to get expected optimization!
 *
 * ```
 * const square = memoize((value) => value * value)`
 * square(2) // == 2
 * ```
 */
declare function memoize<In, Out>(fn: (arg: In) => Out): (arg: In) => Out;
declare function memoizeAsync<In extends any[], Out extends Promise<any>>(fn: (...arg: In) => Out): (...arg: In) => Promise<Out>;
/** Repeat `count` times. Starts with `0` */
declare function forTimes<T = undefined>(count: number, fn: (i: number, count: number) => T): T[];

export { cloneJsonObject, cloneObject, empty, ensureKey, ensureKeyAsync, first, forTimes, last, memoize, memoizeAsync, size };
