import {
  useDisposeWithUtils,
  useEventListener,
  useTimeout
} from "../chunk-KDP637GO.js";
import "../chunk-A4L4FO52.js";
import "../chunk-NEEIRLS6.js";
import "../chunk-WZDTE5W3.js";
import "../chunk-VBSEGKT7.js";
import "../chunk-Q3QHD23G.js";
import "../chunk-CYDFP47V.js";
import "../chunk-URTIMVUU.js";
import "../chunk-DXM327S3.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-NLNCD3ES.js";
import "../chunk-BMLTMNZA.js";
import "../chunk-7QYVSWCZ.js";
import {
  polyfillUsing
} from "../chunk-VI7IQ5ZG.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-5UOZKM4M.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-2DAGZ4FT.js";
import "../chunk-3MLDC2KV.js";
import "../chunk-7G6NITL4.js";
import "../chunk-RSLTBO5X.js";
import "../chunk-I45WP5PM.js";
import "../chunk-MIZOLME5.js";
import "../chunk-AKLYUMQO.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-3KKFLSLG.js";
import "../chunk-PLBFBDKH.js";
import "../chunk-2H4XRKWS.js";
import "../chunk-WJUQ3VXF.js";
import "../chunk-O4GTSXBN.js";
import "../chunk-2OUSR2BE.js";
import "../chunk-ZDZ4EQHN.js";
import "../chunk-PZP2B3FC.js";
import "../chunk-NSJKG6AJ.js";
import "../chunk-XHPHUZE4.js";
import "../chunk-NRGUBMFA.js";
import "../chunk-H564H42Z.js";
import "../chunk-MLCD7TOL.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-LAWEUL6N.js";
import "../chunk-V5ZQ2SFQ.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-EDNCPFSF.js";
import "../chunk-73CVRDI7.js";
import "../chunk-3KQS63H6.js";
import "../chunk-C7K2ID3C.js";
import "../chunk-L324TYGN.js";
import "../chunk-5DS3NT57.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-UO7L7NBK.js";
import "../chunk-QUQRUDWG.js";
import "../chunk-ITJJZ6AV.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-GY34N3KU.js";
import "../chunk-X56GIAWQ.js";
import "../chunk-PN34O4SN.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-HJ22ULAI.js";
import "../chunk-EJGW3W3K.js";
import "../chunk-EAYWSLQT.js";
import {
  __callDispose,
  __using
} from "../chunk-I7BWSAN6.js";

// src/common/dispose-utils.spec.ts
import { vi as jest } from "vitest";
describe("useTimeout", () => {
  it("should call the provided function after the specified timeout", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should cancel the timeout when the disposer function is called", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const disposer = useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    disposer();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).not.toBeCalled();
  });
  it('should add event listener using "on" method if available', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    disposer();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "on" method if available using using', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    polyfillUsing();
    function helper() {
      var _stack = [];
      try {
        const _ = __using(_stack, useEventListener(emitter, eventName, fn, ...args));
        expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
        expect(emitter.off).not.toBeCalled();
      } catch (_2) {
        var _error = _2, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "addEventListener" method if "on" method is not available', () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    disposer();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
  it("should add timeout disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.timeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should add interval disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const interval = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.interval(mockFn, interval);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(interval);
    expect(mockFn).toBeCalled();
  });
  it('should add event listener disposer to the dispose object using "on" method', async () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener disposer to the dispose object using "addEventListener" method', async () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null 2", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    const disposer = dispose.on(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
});
//# sourceMappingURL=dispose-utils.spec.js.map