import {
  debounce,
  throttle
} from "../../chunk-2VA3UGW7.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-I7BWSAN6.js";

// src/common/exec/throttle-debounce.spec.ts
describe("throttle", () => {
  it("should throttle correctly", async () => {
    let ctr = 0;
    expect(ctr).toBe(0);
    const fn = throttle(() => ctr++, { delay: 100 });
    expect(ctr).toBe(0);
    fn();
    expect(ctr).toBe(1);
    fn();
    fn();
    expect(ctr).toBe(1);
    await sleep(50);
    expect(ctr).toBe(1);
    await sleep(100);
    expect(ctr).toBe(2);
    fn();
    expect(ctr).toBe(2);
    await sleep(100);
    expect(ctr).toBe(3);
    fn();
    fn.cancel();
    await sleep(100);
    expect(ctr).toBe(3);
  });
  it("should debounce correctly", async () => {
    let ctr = 0;
    expect(ctr).toBe(0);
    const fn = debounce(() => ctr++, { delay: 100 });
    expect(ctr).toBe(0);
    fn();
    fn();
    expect(ctr).toBe(0);
    await sleep(50);
    fn();
    expect(ctr).toBe(0);
    await sleep(50);
    fn();
    expect(ctr).toBe(0);
    await sleep(50);
    fn();
    expect(ctr).toBe(0);
    await sleep(110);
    expect(ctr).toBe(1);
    fn();
    await sleep(110);
    expect(ctr).toBe(2);
  });
  it("should throttle with least args", async () => {
    let r = 0;
    const fn = throttle(
      (v) => {
        r = v;
      },
      { delay: 50 }
    );
    fn(1);
    expect(r).toBe(1);
    fn(2);
    expect(r).toBe(1);
    fn(3);
    fn(4);
    await sleep(200);
    expect(r).toBe(4);
  });
  it("should debounce long running promise", async () => {
    let r = 0;
    const fn = debounce(
      async (v) => {
        await sleep(200);
        r = v;
      },
      { delay: 50 }
    );
    expect(r).toBe(0);
    void fn(1);
    expect(r).toBe(0);
    await sleep(50);
    expect(r).toBe(0);
    void fn(2);
    await sleep(150);
    void fn(3);
    expect(r).toBe(0);
    await sleep(150);
    expect(r).toBe(1);
    await sleep(300);
    expect(r).toBe(3);
  });
});
//# sourceMappingURL=throttle-debounce.spec.js.map