import {
  getNamespaceFilterString,
  joinLogStrings,
  parseLogLevel,
  useLevelFilter,
  useNamespaceFilter
} from "../../chunk-AKLYUMQO.js";
import {
  LogLevelAll,
  LogLevelDebug,
  LogLevelError,
  LogLevelInfo,
  LogLevelOff,
  LogLevelWarn
} from "../../chunk-YX6CL4KH.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-MLCD7TOL.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/log/log-filter.spec.ts
describe("log-filter", () => {
  it("should match", () => {
    {
      const matches = useNamespaceFilter("a");
      expect(matches.filter).toBe("a");
      expect(matches.accept).toEqual([/^a/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("a*");
      expect(matches.filter).toBe("a*");
      expect(matches.accept).toEqual([/^a.*?/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("a*,b*,-c*");
      expect(matches.filter).toBe("a*,b*,-c*");
      expect(matches.accept).toEqual([/^a.*?/, /^b.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*,-c*");
      expect(matches.filter).toBe("*,-c*");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*,-c");
      expect(matches.filter).toBe("*,-c");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*");
      expect(matches.filter).toBe("*");
      expect(matches.accept).toEqual([]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("b:c")).toBe(true);
    }
  });
  it("should interprete filter right", () => {
    expect(getNamespaceFilterString("")).toEqual("");
    expect(getNamespaceFilterString(0)).toEqual("");
    expect(getNamespaceFilterString(false)).toEqual("");
    expect(getNamespaceFilterString("false")).toEqual("");
    expect(getNamespaceFilterString(null)).toEqual("");
    expect(getNamespaceFilterString("*")).toEqual("*");
    expect(getNamespaceFilterString(1)).toEqual("*");
    expect(getNamespaceFilterString(true)).toEqual("*");
    expect(getNamespaceFilterString("true")).toEqual("*");
    expect(getNamespaceFilterString("a:b")).toEqual("a:b");
  });
  it("should filter by level", () => {
    {
      const levelFilter = useLevelFilter("err");
      expect(levelFilter(LogLevelDebug)).toBe(false);
      expect(levelFilter(LogLevelWarn)).toBe(false);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
    {
      const levelFilter = useLevelFilter("adfdfds");
      expect(levelFilter(LogLevelDebug)).toBe(true);
      expect(levelFilter(LogLevelWarn)).toBe(true);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
    {
      const levelFilter = useLevelFilter(LogLevelWarn);
      expect(levelFilter(LogLevelDebug)).toBe(false);
      expect(levelFilter(LogLevelWarn)).toBe(true);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
  });
  it("should identify log level", () => {
    expect(parseLogLevel(false)).toEqual(LogLevelOff);
    expect(parseLogLevel("info")).toEqual(LogLevelInfo);
    expect(parseLogLevel(LogLevelError)).toEqual(LogLevelError);
    expect(parseLogLevel(true)).toEqual(LogLevelAll);
    expect(parseLogLevel(2)).toEqual(LogLevelWarn);
  });
  it("should join strings", () => {
    expect(joinLogStrings("test")).toEqual(["test"]);
    expect(joinLogStrings("test", "more", 1, 2, 3)).toEqual(["test more", 1, 2, 3]);
    expect(joinLogStrings("test", { a: 1 })).toEqual(["test", { a: 1 }]);
    expect(joinLogStrings("test", "a", "b", true, void 0, null, { a: 1 })).toEqual(["test a", "b", true, void 0, null, { a: 1 }]);
  });
});
//# sourceMappingURL=log-filter.spec.js.map