import {
  LoggerContext
} from "../../chunk-3MLDC2KV.js";
import "../../chunk-7G6NITL4.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AKLYUMQO.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-MLCD7TOL.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = LoggerContext();
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = LoggerContext();
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = LoggerContext();
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = LoggerContext();
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.js.map