import { Disposer, DisposerFunction } from '../dispose-types.cjs';
import { Emitter } from './emitter.cjs';
import '../global.cjs';
import '../log/log.cjs';
import '../log/log-console-original.cjs';
import '../schema/args.cjs';
import '../log/log-base.cjs';
import '../schema/types.cjs';

/** See http://developer.mozilla.org/en-US/docs/Web/API/MessageEvent */
interface ChannelMessageEvent<T = any> {
    data: T;
    origin?: string;
    lastEventId?: string;
}
/**
 * Inspired by
 * http://developer.mozilla.org/en-US/docs/Web/API/BroadcastChannel
 * https://deno.com/deploy/docs/runtime-broadcast-channel
 */
declare abstract class Channel<T = any> extends Emitter<{
    message: (event: ChannelMessageEvent<T>) => void;
    messageerror: (event: ChannelMessageEvent<T>) => void;
    connect: () => void;
    disconnect: () => void;
    close: () => void;
}> {
    id: string;
    abstract isConnected?: boolean;
    abstract postMessage(data: T): void;
    dispose: ((strictSync?: boolean) => Promise<any> | void) & {
        disposed: number;
        add: (obj?: Disposer) => DisposerFunction | undefined;
        remove: (disposable: Disposer) => Promise<void> | void;
        track: (obj?: Disposer) => DisposerFunction | undefined;
        untrack: (disposable: Disposer) => Promise<void> | void;
        dispose: (strictSync?: boolean) => Promise<any> | void;
        disposeSync: () => void;
        sync: () => void;
        exec: (strictSync?: boolean) => Promise<any> | void;
        getSize(): number;
        isDisposed(): boolean;
        [Symbol.dispose](): void | Promise<any>;
        [Symbol.asyncDispose](): Promise<any>;
    };
    /** @deprecated use .dispose() */
    close(): void;
}

export { Channel, type ChannelMessageEvent };
