import { UseStringHashPool } from '../data/string-hash-pool.js';
import { LoggerInterface } from '../log/log-base.js';
import { Pipe } from './pipe.js';

type ArgumentsType<T> = T extends (...args: infer A) => any ? A : never;
type ReturnType<T> = T extends (...args: any) => infer R ? R : never;
interface RPCOptionsBasic extends Pipe {
    /** No return values expected */
    onlyEvents?: boolean;
    /** Maximum timeout for waiting for response, in milliseconds */
    timeout?: number;
    /** Custom logger */
    log?: LoggerInterface;
    /** Custom error handler */
    onError?: (error: Error, functionName: string, args: any[]) => boolean | void;
    /** Custom error handler for timeouts */
    onTimeoutError?: (functionName: string, args: any[]) => boolean | void;
    /** Throw execptions. Default: true */
    exceptions?: boolean;
    /**  */
    stringHashPool?: UseStringHashPool;
}
interface RPCOptions<Remote> extends RPCOptionsBasic {
    /** Names of remote functions that do not need response. */
    eventNames?: (keyof Remote)[];
}
interface RPCFn<T> {
    /** Call the remote function and wait for the result. */
    (...args: ArgumentsType<T>): Promise<Awaited<ReturnType<T>>>;
    /** Send event without asking for response */
    asEvent: (...args: ArgumentsType<T>) => void;
}
type RPCReturn<RemoteFunctions> = {
    [K in keyof RemoteFunctions]: RPCFn<RemoteFunctions[K]>;
};
declare function useRPC<LocalFunctions, RemoteFunctions = LocalFunctions>(functions: LocalFunctions, options: RPCOptions<RemoteFunctions>): RPCReturn<RemoteFunctions>;
declare function useRPCHub(options: RPCOptionsBasic): <LocalFunctions, RemoteFunctions = LocalFunctions>(additionalFunctions?: LocalFunctions, additionalEventNames?: string[]) => RPCReturn<RemoteFunctions>;
type UseRPCHubType = ReturnType<typeof useRPCHub>;

export { type ArgumentsType, type RPCFn, type RPCOptions, type RPCOptionsBasic, type RPCReturn, type ReturnType, type UseRPCHubType, useRPC, useRPCHub };
