import {
  safeTimeout
} from "../chunk-7QYVSWCZ.js";
import "../chunk-I7BWSAN6.js";

// src/common/timeout.spec.ts
import { afterEach, beforeEach, describe, expect, it, vi } from "vitest";
describe("safeTimeout", () => {
  beforeEach(() => {
    vi.useFakeTimers();
  });
  afterEach(() => {
    vi.useRealTimers();
  });
  it("should call the provided function after the specified delay", () => {
    const mockFn = vi.fn();
    const delay = 1e3;
    const dispose = safeTimeout(mockFn, delay);
    vi.advanceTimersByTime(delay);
    expect(mockFn).toHaveBeenCalledTimes(1);
    dispose();
  });
  it("should allow the timer to be disposed of before it executes", () => {
    const mockFn = vi.fn();
    const delay = 1e3;
    const dispose = safeTimeout(mockFn, delay);
    dispose();
    vi.advanceTimersByTime(delay);
    expect(mockFn).toHaveBeenCalledTimes(0);
  });
  it("should allow multiple calls to disposeTimer", () => {
    const mockFn = vi.fn();
    const delay = 1e3;
    const dispose = safeTimeout(mockFn, delay);
    dispose();
    dispose();
    vi.advanceTimersByTime(delay);
    expect(mockFn).toHaveBeenCalledTimes(0);
  });
  it("should work with a zero delay", () => {
    const mockFn = vi.fn();
    const dispose = safeTimeout(mockFn, 0);
    vi.advanceTimersByTime(0);
    expect(mockFn).toHaveBeenCalledTimes(1);
    dispose();
  });
});
//# sourceMappingURL=timeout.spec.js.map